@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use JSON;
 use List::Util qw(first);
 
-our $VERSION = 0.2;
+our $VERSION = 0.3;
 
 sub new {
     my ($class, %params) = @_;
@@ -112,7 +112,7 @@ sub list_scans {
     my ($self, %params) = @_;
 
     my $result = $self->_get('/scans', %params);
-    return $result->{scans} ? @{$result->{scans}} : ();
+    return $result ? @{$result} : ();
 }
 
 sub launch_scan {
@@ -185,18 +185,17 @@ sub download_scan {
 
     croak "missing scan_id parameter" unless $params{scan_id};
     croak "missing file_id parameter" unless $params{file_id};
-    croak "missing filename parameter" unless $params{filename};
 
     my $scan_id = delete $params{scan_id};
     my $file_id = delete $params{file_id};
 
     my $response = $self->{agent}->get(
         $self->{url} . "/scans/$scan_id/export/$file_id/download",
-        ':content_file' => $params{filename}
+        ($params{filename} ? ":content_file => $params{filename}" : "")
     );
 
     if ($response->is_success()) {
-        return 1;
+        return $params{filename} ? 1 : $response->content();
     } else {
         croak "communication error: " . $response->message()
     }
@@ -344,6 +343,17 @@ sub get_plugin_details {
     return $result;
 }
 
+sub get_scanner_id {
+    my ($self, %params) = @_;
+
+    croak "missing name parameter" unless $params{name};
+
+    my $scanner = first { $_->{name} eq $params{name}} $self->list_scanners();
+    return unless $scanner;
+
+    return $scanner->{id};
+}
+
 sub _get {
     my ($self, $path, %params) = @_;
 
@@ -563,6 +573,7 @@ See L<https://your.nessus.server:8834/nessus6-api.html#/resources/scans/delete-h
 =head2 $nessus->download_scan(scan_id => $scan_id, file_id => $file_id, filename => $filename)
 
 Download an exported scan.
+Without filename parameter it will return the content of the file.
 
 See L<https://your.nessus.server:8834/nessus6-api.html#/resources/scans/download> for details.
 
@@ -654,6 +665,10 @@ returns the details about a plugin family
 
 See L<https://your.nessus.server:8834/nessus6-api.html#/resources/plugins/family-details> for details.
 
+=head2 $nessus->get_scanner_id( name => $name )
+
+returns the identifier for the scanner with given name.
+
 =head1 LICENSE
 
 This program is free software: you can redistribute it and/or modify
